@@ -13,7 +13,7 @@ from .client import Client
 # concepts
 from .role import Role
 from .user import User
-from .channel import Channel, PublicTextChannel, PrivateChannel, PublicChannel
+from .channel import Channel, PublicTextChannel, PublicVoiceChannel, PrivateChannel, PublicChannel
 from .guild import Guild, GuildUser
 from .context import Context
 from .message import RawMessage, Message, PublicMessage, PrivateMessage, Event
