@@ -1,7 +1,9 @@
+"""game: components used in playing status"""
 from typing import List
 
 
 class Game:
+    """represents a game used in playing state"""
     id: int
     name: str
     type: int
