@@ -1,5 +1,6 @@
 """guild related stuffs: Guild, ChannelCategory"""
 import logging
+import time
 import warnings
 from typing import List, Union, Dict, IO
 
@@ -7,6 +8,7 @@ from . import api
 from .channel import Channel, public_channel_factory, PublicChannel, PublicVoiceChannel
 from .gateway import Requestable, Gateway
 from .interface import LazyLoadable
+from .permission import PermissionHolder, ChannelPermission
 from .role import Role
 from ._types import ChannelTypes, GuildMuteTypes
 from .user import User
@@ -48,8 +50,25 @@ class GuildUser(User):
         return rt
 
 
-class ChannelCategory(Requestable):
+class GuildBoost:
+    """Guild boost"""
+    user_id: str
+    guild_id: str
+    start_time: int
+    end_time: int
+    user: User
+
+    def __init__(self, **kwargs) -> None:
+        self.user_id = kwargs.get('user_id')
+        self.guild_id = kwargs.get('guild_id')
+        self.start_time = kwargs.get('start_time')
+        self.end_time = kwargs.get('end_time')
+        self.user = User(**kwargs.get('user'), _gate_=kwargs.get('_gate_', None))
+
+
+class ChannelCategory(PermissionHolder, Requestable):
     """represent a channel set"""
+
     id: str
     name: str
     master_id: str
@@ -61,12 +80,20 @@ class ChannelCategory(Requestable):
     def __init__(self, **kwargs):
         self.gate = kwargs.get('_gate_', None)
         self.id = kwargs.get('id')
+        self._update_fields(**kwargs)
+
+    def _update_fields(self, **kwargs):
         self.name = kwargs.get('name')
         self.master_id = kwargs.get('master_id')
         self.guild_id = kwargs.get('_guild_id_')
         self.level = kwargs.get('level')
         self.limit_amount = kwargs.get('limit_amount')
         self._channels = kwargs.get('channels', [])
+        self.permission: ChannelPermission = ChannelPermission(**kwargs)
+
+    async def load(self):
+        self._update_fields(**(await self.gate.exec_req(api.Channel.view(self.id))))
+        self._loaded = True
 
     def append(self, *channel: PublicChannel):
         """append var-len channel(s) into this category"""
@@ -224,10 +251,13 @@ class Guild(LazyLoadable, Requestable):
         users = await self.gate.exec_paged_req(api.Guild.userList(**params), **kwargs)
         return [User(_gate_=self.gate, _lazy_loaded_=True, **i) for i in users]
 
-    async def fetch_joined_channel(self, user: User, page: int = 1, page_size: int = 50) -> List[PublicVoiceChannel]:
+    async def fetch_joined_channel(self,
+                                   user: Union[User, str],
+                                   page: int = 1,
+                                   page_size: int = 50) -> List[PublicVoiceChannel]:
         """fetch the channels which the user joined(public voice channel)"""
         channels = await self.gate.exec_paged_req(
-            api.ChannelUser.getJoinedChannel(page=page, page_size=page_size, guild_id=self.id, user_id=user.id))
+            api.ChannelUser.getJoinedChannel(page=page, page_size=page_size, guild_id=self.id, user_id=unpack_id(user)))
         return [PublicVoiceChannel(_gate_=self.gate, _lazy_loaded_=True, **i) for i in channels]
 
     async def fetch_user(self, user_id: str) -> GuildUser:
@@ -236,9 +266,9 @@ class Guild(LazyLoadable, Requestable):
         user = await self.gate.exec_req(api.User.view(user_id=user_id, guild_id=self.id))
         return GuildUser(guild_id=self.id, _gate_=self.gate, _lazy_loaded_=True, **user)
 
-    async def set_user_nickname(self, user: User, new_nickname: str):
+    async def set_user_nickname(self, user: Union[User, str], new_nickname: str):
         """set the user's nickname in this guild"""
-        await self.gate.exec_req(api.Guild.nickname(guild_id=self.id, nickname=new_nickname, user_id=user.id))
+        await self.gate.exec_req(api.Guild.nickname(guild_id=self.id, nickname=new_nickname, user_id=unpack_id(user)))
 
     async def fetch_roles(self, force_update: bool = True) -> List[Role]:
         """fetch the role list in the guild"""
@@ -261,21 +291,21 @@ class Guild(LazyLoadable, Requestable):
         """delete a role from the guild"""
         return await self.gate.exec_req(api.GuildRole.delete(guild_id=self.id, role_id=unpack_id(role)))
 
-    async def grant_role(self, user: User, role: Union[Role, int]):
+    async def grant_role(self, user: Union[User, str], role: Union[Role, int]):
         """
         docs:
         https://developer.kaiheila.cn/doc/http/guild-role#%E8%B5%8B%E4%BA%88%E7%94%A8%E6%88%B7%E8%A7%92%E8%89%B2
         """
-        role_id = role.id if isinstance(role, Role) else role
-        return await self.gate.exec_req(api.GuildRole.grant(guild_id=self.id, user_id=user.id, role_id=role_id))
+        return await self.gate.exec_req(
+            api.GuildRole.grant(guild_id=self.id, user_id=unpack_id(user), role_id=unpack_id(role)))
 
-    async def revoke_role(self, user: User, role: Union[Role, str]):
+    async def revoke_role(self, user: Union[User, str], role: Union[Role, int]):
         """
         docs:
         https://developer.kaiheila.cn/doc/http/guild-role#%E5%88%A0%E9%99%A4%E7%94%A8%E6%88%B7%E8%A7%92%E8%89%B2
         """
-        role_id = role.id if isinstance(role, Role) else role
-        return await self.gate.exec_req(api.GuildRole.revoke(guild_id=self.id, user_id=user.id, role_id=role_id))
+        return await self.gate.exec_req(
+            api.GuildRole.revoke(guild_id=self.id, user_id=unpack_id(user), role_id=unpack_id(role)))
 
     async def create_channel(self,
                              name: str,
@@ -300,7 +330,7 @@ class Guild(LazyLoadable, Requestable):
             params['voice_quality'] = voice_quality
         return public_channel_factory(self.gate, **(await self.gate.exec_req(api.Channel.create(**params))))
 
-    async def delete_channel(self, channel: Union[str, Channel]):
+    async def delete_channel(self, channel: Union[Channel, str]):
         """delete the channel from the guild"""
         return await self.gate.exec_req(api.Channel.delete(unpack_id(channel)))
 
@@ -365,3 +395,14 @@ class Guild(LazyLoadable, Requestable):
     async def delete_emoji(self, id: str):
         """delete a custom emoji"""
         return await self.gate.exec_req(api.GuildEmoji.delete(id))
+
+    async def fetch_boost(self, start_time: int = 0, end_time: int = int(time.time()), **kwargs) -> List[GuildBoost]:
+        """
+        list the boost in guild.
+
+        :param start_time: start_time time stamp (Sec).
+        :param end_time: end_time time stamp (Sec). Default to now time.
+        """
+        boost_list = await self.gate.exec_paged_req(
+            api.GuildBoost.history(guild_id=self.id, start_time=start_time, end_time=end_time), **kwargs)
+        return [GuildBoost(**item, _gate_=self.gate) for item in boost_list]
